@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2022-2023 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Identical 0.02;
+package Syntax::Operator::Identical 0.03;
 
 use v5.14;
 use warnings;
@@ -176,7 +176,7 @@ sub apply
    foreach (qw( is_identical is_not_identical )) {
       next unless delete $syms{$_};
 
-      $callerpkg //= meta::get_package( $caller );
+      $callerpkg //= meta::package->get( $caller );
 
       $on ? $callerpkg->add_symbol( '&'.$_ => \&{$_} )
           : $callerpkg->remove_symbol( '&'.$_ );
